Changelog
---------

0.1.2 (2018-10-10)
~~~~~~~~~~~~~~~~~~~~~

- Uses session instead of request for bound_messages.
  [href]

- Requires Python 3.6.
  [href]

0.1.1 (2017-11-08)
~~~~~~~~~~~~~~~~~~~~~

- Adds the ability to specify the oder in which messages are loaded.
  [href]

0.1.0 (2017-07-10)
~~~~~~~~~~~~~~~~~~~~~

- Initial Release.
  [href]
